/*
 * Obtain file metadata.
 *
 * Copyright (C) 2018, 2019, 2020 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#include <fsclient/client.h>
#include <systypes/fcntl.h>



int main(int argc, char *argv[])
{
  char buffer[] = "Some data for a file.";
  file_descriptor_t *desc;
  struct stat st;

  if (argc < 2)
  {
    printf("Need a filename.\n");
    return 1;
  }

  printf("Opening %s...\n", argv[1]);

  desc = client_open(argv[1], O_RDWR | O_CREAT, 0);

  if (desc == NULL)
  {
    printf("Could not open file.\n");
    return 1;
  }

  printf("Writing...\n");

  client_write(desc, buffer, strlen(buffer));
  client_flush(desc);

  printf("Written to file.\n");

  if (client_fstat(desc, &st))
  {
    printf("Failed to get metadata.\n");
    return 1;
  }

  printf("mode: %o\n", st.st_mode);
  printf("uid: %d\n", st.st_uid);
  printf("gid: %d\n", st.st_gid);
  printf("size: %ld\n", st.st_size);

  client_close(desc);

  printf("\nClosed.\n");
  return 0;
}
